@@ -23,12 +23,26 @@ class DictAliaser(odict):
     ``__getitem__`` -> unalias
     """
     implements(IAliaser, IFullMapping)
+    
+    def __init__(self, data=(), strict=True):
+        super(DictAliaser, self).__init__(data)
+        self.strict = strict
 
     def alias(self, key):
-        return ReverseMapping(self)[key]
+        try:
+            return ReverseMapping(self)[key]
+        except KeyError, e:
+            if not self.strict:
+                return key
+            raise e
     
     def unalias(self, aliased_key):
-        return self[aliased_key]
+        try:
+            return self[aliased_key]
+        except KeyError, e:
+            if not self.strict:
+                return aliased_key
+            raise e
 
 
 class PrefixAliaser(object):
@@ -79,12 +93,6 @@ class SuffixAliaser(object):
         return suffixed_key[:-len(suffix)]
 
 
-# XXX: what was that again?
-# rnix: no idea
-class NodespaceAliases(dict):
-    pass
-    
-
 class AliaserChain(object):
     """A chain of aliasers.
 
@@ -121,9 +129,11 @@ class PrefixSuffixAliaser(AliaserChain):
             SuffixAliaser(suffix))
 
 
-class NamedAliasers(dict):
-    """A dictionary storing aliasers by name.
-    """
+#class NamedAliasers(dict):
+#    """A dictionary storing aliasers by name.
+#    
+#    XXX
+#    """
 
 
 class AliasedNodespace(object):
@@ -134,8 +144,6 @@ class AliasedNodespace(object):
 
     Future additional mode: children are wrapped, wrapper knows name and we are
     parent of wrapper.
-    
-    XXX: make me a Part -> Flo, would you be so kind?
     """
     __metaclass__ = plumber
     __plumbing__ = (
@@ -146,28 +154,22 @@ class AliasedNodespace(object):
     
     def __init__(self, context, aliaser=None):
         """
-        ``context``
+        context
             the node whose children to alias
-        ``aliaser``
+            
+        aliaser
             the aliaser to be used
         """
-        #XXX: is just taking over the name ok for all use cases? 
-        #super(AliasedNodespace, self).__init__(context.__name__)
+        # XXX: is just taking over the name ok for all use cases? 
+        # XXX: case where not? -rn
+        #super(AliasedNodespace, self).__init__(context.name)
         
-        self.__name__ = context.__name__
+        self.__name__ = context.name
         self.__parent__ = None
         
         self.context = context
         self.aliaser = aliaser
 
-    @property
-    def changed(self):
-        return self.context.changed
-
-    @property
-    def __call__(self):
-        return self.context.__call__()
-
     def __delitem__(self, key):
         unaliased_key = self.aliaser and self.aliaser.unalias(key) or key
         try:
@@ -184,11 +186,8 @@ class AliasedNodespace(object):
 
     def __setitem__(self, key, val):
         unaliased_key = self.aliaser and self.aliaser.unalias(key) or key
-        try:
-            self.context[unaliased_key] = val
-        except KeyError:
-            raise KeyError(key)
-
+        self.context[unaliased_key] = val
+    
     def __iter__(self):
         for key in self.context:
             try:
@@ -199,7 +198,9 @@ class AliasedNodespace(object):
                     continue
                 # no whitelisting and a KeyError on our internal data: that's
                 # bad! Most probably not triggered on _Node but a subclass
-                raise RuntimeError(u"Inconsist internal node state")
+                # XXX: test case showing this.
+                raise RuntimeError(                         #pragma NO COVERAGE
+                    u"Inconsist internal node state")       #pragma NO COVERAGE
     
     def __repr__(self):
-        return "Aliased " + self.context.__repr__()
+        return "Aliased " + self.context.__repr__()
\ No newline at end of file
